@@ -158,9 +158,6 @@ void MarbleWidgetPrivate::construct()
     m_widget->setMinimumSize( 200, 300 );
     m_widget->setFocusPolicy( Qt::WheelFocus );
     m_widget->setFocus( Qt::OtherFocusReason );
-#if QT_VERSION >= 0x40600
-    m_widget->grabGesture(Qt::PinchGesture);
-#endif
 
     // Initialize the map and forward some signals.
     m_map->setSize( m_widget->width(), m_widget->height() );
