@@ -107,6 +107,8 @@ public:
 
     AlternativeRoutesModel* m_alternativeRoutesModel;
 
+    ViewContext m_viewContext;
+
     bool m_viewportChanged;
 
     /** Constructor */
@@ -239,7 +241,7 @@ void RoutingLayerPrivate::renderPlacemarks( GeoPainter *painter )
 
 void RoutingLayerPrivate::renderAlternativeRoutes( GeoPainter *painter )
 {
-    if ( m_viewportChanged ) {
+    if ( m_viewportChanged && m_viewContext == Still ) {
         m_alternativeRouteRegions.clear();
     }
 
@@ -253,7 +255,7 @@ void RoutingLayerPrivate::renderAlternativeRoutes( GeoPainter *painter )
             GeoDataLineString* points = AlternativeRoutesModel::waypoints( route );
             if ( points ) {
                 painter->drawPolyline( *points );
-                if ( m_viewportChanged ) {
+                if ( m_viewportChanged && m_viewContext == Still ) {
                     QRegion region = painter->regionFromPolyline( *points, 8 );
                     m_alternativeRouteRegions.push_back( RequestRegion( i, region ) );
                 }
@@ -264,7 +266,6 @@ void RoutingLayerPrivate::renderAlternativeRoutes( GeoPainter *painter )
 
 void RoutingLayerPrivate::renderRoute( GeoPainter *painter )
 {
-    m_instructionRegions.clear();
     GeoDataLineString waypoints = m_routingModel->route().path();
 
     QPen bluePen( alphaAdjusted( oxygenSkyBlue4, 200 ) );
@@ -275,7 +276,7 @@ void RoutingLayerPrivate::renderRoute( GeoPainter *painter )
     painter->setPen( bluePen );
 
     painter->drawPolyline( waypoints );
-    if ( m_viewportChanged ) {
+    if ( m_viewportChanged && m_viewContext == Still ) {
         int const offset = MarbleGlobal::getInstance()->profiles() & MarbleGlobal::SmallScreen ? 24 : 8;
         m_routeRegion = painter->regionFromPolyline( waypoints, offset );
     }
@@ -318,6 +319,11 @@ void RoutingLayerPrivate::renderRoute( GeoPainter *painter )
         }
     }
 
+    if ( m_viewContext == Animation ) {
+        return;
+    }
+
+    m_instructionRegions.clear();
     for ( int i = 0; i < m_routingModel->rowCount(); ++i ) {
         QModelIndex index = m_routingModel->index( i, 0 );
         GeoDataCoordinates pos = qVariantValue<GeoDataCoordinates>( index.data( MarblePlacemarkModel::CoordinateRole ) );
@@ -719,7 +725,9 @@ bool RoutingLayer::render( GeoPainter *painter, ViewportParams *viewport,
     }
 
     painter->restore();
-    d->m_viewportChanged = false;
+    if ( d->m_viewportChanged && d->m_viewContext == Still ) {
+        d->m_viewportChanged = false;
+    }
     return true;
 }
 
@@ -847,6 +855,11 @@ void RoutingLayer::setViewportChanged()
     d->m_viewportChanged = true;
 }
 
+void RoutingLayer::setViewContext( ViewContext viewContext )
+{
+    d->m_viewContext = viewContext;
+}
+
 } // namespace Marble
 
 #include "RoutingLayer.moc"
